@@ -17,13 +17,13 @@ App::XML::DocBook::Docmake - translate DocBook/XML to other formats
 
 =head1 VERSION
 
-Version 0.0403
+Version 0.0404
 
 =cut
 
 use vars qw($VERSION);
 
-$VERSION = '0.0403';
+$VERSION = '0.0404';
 
 __PACKAGE__->mk_accessors(qw(
     _base_path
@@ -493,6 +493,11 @@ sub _run_xslt_and_from_fo
 
     my $xslt_output_path = $self->_output_path();
 
+    if (!defined ($xslt_output_path))
+    {
+        die "No -o flag was specified. See the help.";
+    }
+
     # TODO : do something meaningful if a period (".") is not present
     if ($xslt_output_path !~ m{\.}ms)
     {
